# Vision (beta version)
Visual testing framework. Combining selenium and computer vision.

<a href="https://www.nemonet.io" target="_blank">Vision</a>

## What is Vision?
```
It is a web app testing framework that combines selenium and computer vision written in python.

There are several good selenium automation frameworks out there. Why then make another one? 
- Most of the better frameworks are not free for use.
- Most frameworks are selenium only.
- I needed a framework that is open source.
- I needed a framework that needs minimal coding
```
## Getting started
### Before installation
- Python is installed on your system
- Chrome web browser installed <a href="https://www.google.com/intl/en/chrome/" target="_blank">`Download Chrome`</a>
- Chrome web driver installed <a href="https://chromedriver.chromium.org/downloads" target="_blank">`ChromeDriver - WebDriver for Chrome`</a>
- test if you can start the web browser
- test if you can start chromedriver from commandline
- best  to install the package under <a href="https://docs.python.org/3.6/library/venv.html" target="_blank">`python virtual environment`</a> 
- install https://graphviz.org  
- install <a href="https://www.google.com/intl/en/chrome/" target="_blank">`Graphviz for your environment`</a>

[Install details](install.md)

### Installation
```
pip install nemonet
```

## Run example
- open a command prompt
- clone following repo : git clone https://github.com/janrum/visiontestfiles.git
- cd into visiontestfiles
- vision selenium-dev
